==> qore-1.5.1.tar.bz2: qore-1.5.1/docs/modules/Mapper/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore Mapper Module Reference", "index.html", [
    [ "Mapper Module", "index.html", [
      [ "Mapper Module Introduction", "index.html#mapperintro", null ],
      [ "Mapper Examples", "index.html#mapperexamples", null ],
      [ "Mapper Specification Format", "index.html#mapperkeys", null ],
      [ "Mapper Options", "index.html#mapperoptions", null ],
      [ "Mapper Runtime Options", "index.html#mapper_runtime_handling", null ],
      [ "Release Notes", "index.html#mapperrelnotes", [
        [ "Mapper v1.5.8", "index.html#mapperv1_5_8", null ],
        [ "Mapper v1.5.7", "index.html#mapperv1_5_7", null ],
        [ "Mapper v1.5.6", "index.html#mapperv1_5_6", null ],
        [ "Mapper v1.5.5", "index.html#mapperv1_5_5", null ],
        [ "Mapper v1.5.4", "index.html#mapperv1_5_4", null ],
        [ "Mapper v1.5.3", "index.html#mapperv1_5_3", null ],
        [ "Mapper v1.5.2", "index.html#mapperv1_5_2", null ],
        [ "Mapper v1.5.1", "index.html#mapperv1_5_1", null ],
        [ "Mapper v1.5", "index.html#mapperv1_5", null ],
        [ "Mapper v1.4.1", "index.html#mapperv1_4_1", null ],
        [ "Mapper v1.4", "index.html#mapperv1_4", null ],
        [ "Mapper v1.3.1", "index.html#mapperv1_3_1", null ],
        [ "Mapper v1.3", "index.html#mapperv1_3", null ],
        [ "Mapper v1.2", "index.html#mapperv1_2", null ],
        [ "Mapper v1.1", "index.html#mapperv1_1", null ],
        [ "Mapper v1.0", "index.html#mapperv1_0", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-1.6.0.tar.bz2: qore-1.6.0/docs/modules/Mapper/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore Mapper Module Reference", "index.html", [
    [ "Mapper Module", "index.html", [
      [ "Mapper Module Introduction", "index.html#mapperintro", null ],
      [ "Mapper Examples", "index.html#mapperexamples", null ],
      [ "Mapper Specification Format", "index.html#mapperkeys", null ],
      [ "Mapper Options", "index.html#mapperoptions", null ],
      [ "Mapper Runtime Options", "index.html#mapper_runtime_handling", null ],
      [ "Release Notes", "index.html#mapperrelnotes", [
        [ "Mapper v1.6", "index.html#mapperv1_6", null ],
        [ "Mapper v1.5.9", "index.html#mapperv1_5_9", null ],
        [ "Mapper v1.5.8", "index.html#mapperv1_5_8", null ],
        [ "Mapper v1.5.7", "index.html#mapperv1_5_7", null ],
        [ "Mapper v1.5.6", "index.html#mapperv1_5_6", null ],
        [ "Mapper v1.5.5", "index.html#mapperv1_5_5", null ],
        [ "Mapper v1.5.4", "index.html#mapperv1_5_4", null ],
        [ "Mapper v1.5.3", "index.html#mapperv1_5_3", null ],
        [ "Mapper v1.5.2", "index.html#mapperv1_5_2", null ],
        [ "Mapper v1.5.1", "index.html#mapperv1_5_1", null ],
        [ "Mapper v1.5", "index.html#mapperv1_5", null ],
        [ "Mapper v1.4.1", "index.html#mapperv1_4_1", null ],
        [ "Mapper v1.4", "index.html#mapperv1_4", null ],
        [ "Mapper v1.3.1", "index.html#mapperv1_3_1", null ],
        [ "Mapper v1.3", "index.html#mapperv1_3", null ],
        [ "Mapper v1.2", "index.html#mapperv1_2", null ],
        [ "Mapper v1.1", "index.html#mapperv1_1", null ],
        [ "Mapper v1.0", "index.html#mapperv1_0", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
